@@ -22,6 +22,7 @@
 
 #include <tqlayout.h>
 #include <kurl.h>
+#include <kstandarddirs.h>
 #include <tdelocale.h>
 #include <tdeio/netaccess.h>
 #include <tdeio/renamedlg.h>
@@ -691,7 +692,39 @@ void DolphinView::updateURL()
         return;
     }
 
-    if (fileItem->isDir()) {
+    if (fileItem->isDir())
+		{
+				TQString itemMimeType = fileItem->mimetype();
+				if (itemMimeType.contains("encrypted_locked") || itemMimeType.contains("encrypted_unlocked"))
+				{
+						// Default action for media encrypted disks is either lock or unlock based on current status
+						TQString lockingAction = TQString::null;
+						if (itemMimeType.contains("encrypted_locked"))
+						{
+								lockingAction = "d3lphin/servicemenus/media_unlock.desktop";
+						}
+						else if (itemMimeType.contains("encrypted_unlocked"))
+						{
+								lockingAction = "d3lphin/servicemenus/media_lock.desktop";
+						}
+						if (!lockingAction.isEmpty())
+						{
+								TQString lockingService = TDEGlobal::dirs()->findResource("data", lockingAction);
+								if (!lockingService.isEmpty())
+								{
+										TQValueList<KDEDesktopMimeType::Service> serviceList = KDEDesktopMimeType::userDefinedServices(lockingService, fileItem->url().isLocalFile());
+										if (serviceList.count() == 1)
+										{
+												KURL::List m_lstURLs;
+												m_lstURLs.append(fileItem->url());
+												KDEDesktopMimeType::executeService(m_lstURLs, serviceList[0]);
+												Dolphin::mainWin().refreshViews();
+												return;
+										}
+								}
+						}
+				}
+
         // Prefer the local path over the URL. This assures that the
         // volume space information is correct. Assuming that the URL is media:/sda1,
         // and the local path is /windows/C: For the URL the space info is related
@@ -708,16 +741,18 @@ void DolphinView::updateURL()
     else if (fileItem->isFile()) {
        // allow to browse through ZIP and tar files
        KMimeType::Ptr mime = fileItem->mimeTypePtr();
-       if (mime->is("application/x-zip")) {
+       if( mime->is("application/x-zip") || mime->is("application/x-jar") ) {
            KURL url = fileItem->url();
            url.setProtocol("zip");
            setURL(url);
        }
-       else if (mime->is("application/x-tar") ||
+       else if( mime->is("application/x-tar")  ||
                 mime->is("application/x-tarz") ||
-                mime->is("application/x-tbz") ||
-                mime->is("application/x-tgz") ||
-                mime->is("application/x-tzo")) {
+                mime->is("application/x-tbz")  ||
+                mime->is("application/x-tgz")  ||
+                mime->is("application/x-tzo")  ||
+                mime->is("application/x-txz")  ||
+                mime->is("application/x-tlzma") ) {
            KURL url = fileItem->url();
            url.setProtocol("tar");
            setURL(url);
