@@ -22,6 +22,7 @@
 #include "urlnavigator.h"
 
 #include <assert.h>
+#include <dcopref.h>
 #include <kurl.h>
 #include <tqobjectlist.h>
 #include <tqcombobox.h>
@@ -39,6 +40,7 @@
 #include <kurlcombobox.h>
 #include <kurlcompletion.h>
 #include <kbookmarkmanager.h>
+#include <kstandarddirs.h>
 
 #include "dolphin.h"
 #include "dolphinsettings.h"
@@ -117,17 +119,18 @@ void URLNavigator::setURL(const KURL& url)
 {
     TQString urlStr(url.prettyURL());
 
-    if (url.protocol() == "zip") {
+    if (url.protocol() == "zip")
+    {
        bool stillInside = false;
-       if (KMimeType::findByPath(url.url(-1))
-           ->is("application/x-zip")) {
+       if( KMimeType::findByPath( url.url(-1) )->is("application/x-zip") ||
+           KMimeType::findByPath( url.url(-1) )->is("application/x-jar") ) {
            stillInside = true;
        }
        else {
            KURL url1 = url.upURL();
            while (url1 != url1.upURL()) {
-               if (KMimeType::findByPath(url1.url(-1))
-                   ->is("application/x-zip")) {
+               if( KMimeType::findByPath( url1.url(-1) )->is("application/x-zip") ||
+                   KMimeType::findByPath( url1.url(-1) )->is("application/x-jar") ) {
                    stillInside = true;
                    break;
                }
@@ -145,11 +148,13 @@ void URLNavigator::setURL(const KURL& url)
        bool stillInside = false;
        KMimeType::Ptr kmp = 
            KMimeType::findByPath(url.url(-1));
-       if (kmp->is("application/x-tar") ||
+       if( kmp->is("application/x-tar")  ||
            kmp->is("application/x-tarz") ||
-           kmp->is("application/x-tbz") || 
-           kmp->is("application/x-tgz") || 
-           kmp->is("application/x-tzo")
+           kmp->is("application/x-tbz")  || 
+           kmp->is("application/x-tgz")  || 
+           kmp->is("application/x-tzo")  ||
+           kmp->is("application/x-txz")  ||
+           kmp->is("application/x-tlzma")
            ) {
            stillInside = true;
        }
@@ -158,11 +163,13 @@ void URLNavigator::setURL(const KURL& url)
            while (url1 != url1.upURL()) {
                KMimeType::Ptr kmp =
                    KMimeType::findByPath(url1.url(-1));
-               if (kmp->is("application/x-tar") ||
+               if( kmp->is("application/x-tar")  ||
                    kmp->is("application/x-tarz") ||
-                   kmp->is("application/x-tbz") || 
-                   kmp->is("application/x-tgz") || 
-                   kmp->is("application/x-tzo")
+                   kmp->is("application/x-tbz")  || 
+                   kmp->is("application/x-tgz")  || 
+                   kmp->is("application/x-tzo")  ||
+                   kmp->is("application/x-txz")  ||
+                   kmp->is("application/x-tlzma")
                    ) {
                    stillInside = true;
                    break;
@@ -176,6 +183,35 @@ void URLNavigator::setURL(const KURL& url)
            urlStr = url.path();
        }
     }
+    else if (urlStr.startsWith("system:/media") || urlStr.startsWith("media:/"))
+    {
+        DCOPRef mediamanager("kded", "mediamanager");
+        DCOPReply reply = mediamanager.call("mimeType", urlStr );
+        if (reply.isValid())
+        {
+            TQString itemMimeType = reply;
+            if (itemMimeType.contains("encrypted"))
+            {
+                if (itemMimeType.contains("encrypted_locked"))
+                {
+                    TQString lockingService = TDEGlobal::dirs()->findResource("data", "d3lphin/servicemenus/media_unlock.desktop");
+                    if (!lockingService.isEmpty())
+                    {
+                        TQValueList<KDEDesktopMimeType::Service> serviceList = KDEDesktopMimeType::userDefinedServices(lockingService, url.isLocalFile());
+                        if (serviceList.count() == 1)
+                        {
+                            KURL::List m_lstURLs;
+                            m_lstURLs.append(url);
+                            KDEDesktopMimeType::executeService(m_lstURLs, serviceList[0]);
+                        }
+                    }
+                }
+                setURL(KURL("system:/media"));
+                return;
+            }
+        }
+
+    }
 
 
     if (urlStr.at(0) == '~') {
